import { HttpClient } from './HttpClient';
import { Indent } from './Indent';
export { HttpClient } from './HttpClient';
export { Indent } from './Indent';
export type Options = {
    input: string | Record<string, any>;
    output: string;
    httpClient?: HttpClient;
    clientName?: string;
    useOptions?: boolean;
    useUnionTypes?: boolean;
    exportCore?: boolean;
    exportServices?: boolean;
    exportModels?: boolean;
    exportClient?: boolean;
    exportIndex?: boolean;
    exportSchemas?: boolean;
    indent?: Indent;
    postfixServices?: string;
    postfixModels?: string;
    request?: string;
    serviceTemplate?: string;
    clientTemplate?: string;
    indexTemplate?: string;
    write?: boolean;
};
/**
 * Generate the OpenAPI client. This method will read the OpenAPI specification and based on the
 * given language it will generate the client, including the typed models, validation schemas,
 * service layer, etc.
 * @param input The relative location of the OpenAPI spec
 * @param output The relative location of the output directory
 * @param httpClient The selected httpClient (fetch, xhr, node or axios)
 * @param clientName Custom client class name
 * @param useOptions Use options or arguments functions
 * @param useUnionTypes Use union types instead of enums
 * @param exportCore Generate core client classes
 * @param exportServices Generate services
 * @param exportModels Generate models
 * @param exportSchemas Generate schemas
 * @param indent Indentation options (4, 2 or tab)
 * @param postfixServices Service name postfix
 * @param postfixModels Model name postfix
 * @param request Path to custom request file
 * @param write Write the files to disk (true or false)
 */
export declare const generate: ({ input, output, httpClient, clientName, useOptions, useUnionTypes, exportCore, exportServices, exportModels, exportClient, exportIndex, exportSchemas, indent, postfixServices, postfixModels, request, serviceTemplate, clientTemplate, indexTemplate, write, }: Options) => Promise<void>;
declare const _default: {
    HttpClient: typeof HttpClient;
    generate: ({ input, output, httpClient, clientName, useOptions, useUnionTypes, exportCore, exportServices, exportModels, exportClient, exportIndex, exportSchemas, indent, postfixServices, postfixModels, request, serviceTemplate, clientTemplate, indexTemplate, write, }: Options) => Promise<void>;
};
export default _default;
//# sourceMappingURL=index.d.ts.map